@@ -25,20 +25,19 @@ class DeleteClusterRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'DeleteCluster')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ClusterId(self):
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_ReleaseInstance(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_ReleaseInstance(self): # String
 		return self.get_query_params().get('ReleaseInstance')
 
-	def set_ReleaseInstance(self,ReleaseInstance):
-		self.add_query_param('ReleaseInstance',ReleaseInstance)
\ No newline at end of file
+	def set_ReleaseInstance(self, ReleaseInstance):  # String
+		self.add_query_param('ReleaseInstance', ReleaseInstance)
