@@ -25,20 +25,19 @@ class ListInvocationStatusRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'ListInvocationStatus')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ClusterId(self):
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_CommandId(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_CommandId(self): # String
 		return self.get_query_params().get('CommandId')
 
-	def set_CommandId(self,CommandId):
-		self.add_query_param('CommandId',CommandId)
\ No newline at end of file
+	def set_CommandId(self, CommandId):  # String
+		self.add_query_param('CommandId', CommandId)
