@@ -25,20 +25,19 @@ class ListSoftwaresRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'ListSoftwares')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_OsTag(self):
+	def get_OsTag(self): # String
 		return self.get_query_params().get('OsTag')
 
-	def set_OsTag(self,OsTag):
-		self.add_query_param('OsTag',OsTag)
-
-	def get_EhpcVersion(self):
+	def set_OsTag(self, OsTag):  # String
+		self.add_query_param('OsTag', OsTag)
+	def get_EhpcVersion(self): # String
 		return self.get_query_params().get('EhpcVersion')
 
-	def set_EhpcVersion(self,EhpcVersion):
-		self.add_query_param('EhpcVersion',EhpcVersion)
\ No newline at end of file
+	def set_EhpcVersion(self, EhpcVersion):  # String
+		self.add_query_param('EhpcVersion', EhpcVersion)
