@@ -25,24 +25,23 @@ class ModifyUserGroupsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'ModifyUserGroups')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ClusterId(self):
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_Users(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_Users(self): # RepeatList
 		return self.get_query_params().get('User')
 
-	def set_Users(self, Users):
-		for depth1 in range(len(Users)):
-			if Users[depth1].get('Name') is not None:
-				self.add_query_param('User.' + str(depth1 + 1) + '.Name', Users[depth1].get('Name'))
-			if Users[depth1].get('Group') is not None:
-				self.add_query_param('User.' + str(depth1 + 1) + '.Group', Users[depth1].get('Group'))
\ No newline at end of file
+	def set_Users(self, User):  # RepeatList
+		for depth1 in range(len(User)):
+			if User[depth1].get('Name') is not None:
+				self.add_query_param('User.' + str(depth1 + 1) + '.Name', User[depth1].get('Name'))
+			if User[depth1].get('Group') is not None:
+				self.add_query_param('User.' + str(depth1 + 1) + '.Group', User[depth1].get('Group'))
