@@ -25,26 +25,24 @@ class StartVisualServiceRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'StartVisualService')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ClusterId(self):
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_Port(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_Port(self): # Integer
 		return self.get_query_params().get('Port')
 
-	def set_Port(self,Port):
-		self.add_query_param('Port',Port)
-
-	def get_CidrIp(self):
+	def set_Port(self, Port):  # Integer
+		self.add_query_param('Port', Port)
+	def get_CidrIp(self): # String
 		return self.get_query_params().get('CidrIp')
 
-	def set_CidrIp(self,CidrIp):
-		self.add_query_param('CidrIp',CidrIp)
\ No newline at end of file
+	def set_CidrIp(self, CidrIp):  # String
+		self.add_query_param('CidrIp', CidrIp)
